@@ -9,7 +9,7 @@ def encrypt(key: str, content: str):
 
 
 def decrypt(key: str, content: str):
-    return PKCS1_OAEP.new(pkey).decrypt(base64.b64decode(content.encode('utf-8'))).decode('utf-8')
+    return PKCS1_OAEP.new(key).decrypt(base64.b64decode(content.encode('utf-8'))).decode('utf-8')
 
 
 def big_encrypt(key: str, content: str) -> (str, str):
